@@ -4,7 +4,7 @@
 
 anova.rcr <-
 function (object, ...){
-  if (sum(is.na(object$coefficients)) > 0) return (cat ("Error: Null coefficient values. Check individual coefficients and model fits."))
+  if (sum(is.na(object$coefficients)) > 0) return (cat ("Error: Null coefficient values. Check individual coefficients and model fits.\n\n"))
   
   nfactors = length (levels (object$factors))
   factors = levels (object$factors)
